summaryrefslogtreecommitdiffstats
path: root/kttsd/plugins/flite/fliteconf.h
diff options
context:
space:
mode:
Diffstat (limited to 'kttsd/plugins/flite/fliteconf.h')
-rw-r--r--kttsd/plugins/flite/fliteconf.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kttsd/plugins/flite/fliteconf.h b/kttsd/plugins/flite/fliteconf.h
index aa26c7b..6d5ff06 100644
--- a/kttsd/plugins/flite/fliteconf.h
+++ b/kttsd/plugins/flite/fliteconf.h
@@ -25,7 +25,7 @@
#define _FLITECONF_H_
// Qt includes.
-#include <qstring.h>
+#include <tqstring.h>
// KDE includes.
#include <kconfig.h>
@@ -45,7 +45,7 @@ class FliteConf : public PlugInConf {
public:
/** Constructor */
- FliteConf( QWidget* parent = 0, const char* name = 0, const QStringList &args = QStringList());
+ FliteConf( TQWidget* parent = 0, const char* name = 0, const TQStringList &args = TQStringList());
/** Destructor */
~FliteConf();
@@ -57,14 +57,14 @@ class FliteConf : public PlugInConf {
* valid settings. NOTE that this is not called after the modules is loaded,
* so you probably want to call this method in the constructor.
*/
- void load(KConfig *config, const QString &configGroup);
+ void load(KConfig *config, const TQString &configGroup);
/** This function gets called when the user wants to save the settings in
* the user interface, updating the config files or wherever the
* configuration is stored. The method is called when the user clicks "Apply"
* or "Ok".
*/
- void save(KConfig *config, const QString &configGroup);
+ void save(KConfig *config, const TQString &configGroup);
/** This function is called to set the settings in the module to sensible
* default values. It gets called when hitting the "Default" button. The
@@ -77,7 +77,7 @@ class FliteConf : public PlugInConf {
* This function informs the plugin of the desired language to be spoken
* by the plugin. The plugin should attempt to adapt itself to the
* specified language code, choosing sensible defaults if necessary.
* If the passed-in code is QString::null, no specific language has
* been chosen.
* @param lang The desired language code or Null if none.
*
@@ -89,16 +89,16 @@ class FliteConf : public PlugInConf {
* not the given country, treat it as though the country
* code were not specified, i.e., adapt to the given language.
*/
- void setDesiredLanguage(const QString &lang);
+ void setDesiredLanguage(const TQString &lang);
/**
* Return fully-specified talker code for the configured plugin. This code
* uniquely identifies the configured instance of the plugin and distinquishes
* one instance from another. If the plugin has not been fully configured,
* i.e., cannot yet synthesize, return QString::null.
* @return Fully-specified talker code.
*/
- QString getTalkerCode();
+ TQString getTalkerCode();
private slots:
void configChanged(){
@@ -111,13 +111,13 @@ class FliteConf : public PlugInConf {
private:
// Language code.
- QString m_languageCode;
+ TQString m_languageCode;
// Configuration Widget.
FliteConfWidget* m_widget;
// Flite synthesizer.
FliteProc* m_fliteProc;
// Synthesized wave file name.
- QString m_waveFile;
+ TQString m_waveFile;
// Progress dialog.
KProgressDialog* m_progressDlg;
};
@@ -77,7 +77,7 @@ class FliteConf : public PlugInConf {
* by the plugin. The plugin should attempt to adapt itself to the
* specified language code, choosing sensible defaults if necessary.
- * If the passed-in code is QString::null, no specific language has
+ * If the passed-in code is TQString::null, no specific language has
* been chosen.
* @param lang The desired language code or Null if none.
@@ -89,16 +89,16 @@ class FliteConf : public PlugInConf {
* uniquely identifies the configured instance of the plugin and distinquishes
* one instance from another. If the plugin has not been fully configured,
- * i.e., cannot yet synthesize, return QString::null.
+ * i.e., cannot yet synthesize, return TQString::null.
* @return Fully-specified talker code.
*/